@@ -4,14 +4,14 @@ import matplotlib.pyplot as plt
 from pathlib import Path
 from datetime import datetime, timedelta
 from .qcutils import stats4qc, iqr_qc, glbdec, despike, detrend, deplatform
-from .CO2 import center_rolling, retuning, quality_control_co2
+from .CO2 import center_rolling, retuning, qc_CO2
 from .Ts import get_minute_std, qc_Ts
 from .mutual import two_systems
 
 __all__ = [
     'np', 'pd', 'plt', 'Path', 'datetime', 'timedelta',
     'stats4qc', 'iqr_qc', 'glbdec', 'despike', 'detrend', 'deplatform',
-    'center_rolling', 'retuning', 'quality_control_co2',
+    'center_rolling', 'retuning', 'qc_CO2',
     'get_minute_std', 'qc_Ts',
     'two_systems'
     ]
\ No newline at end of file
